/*
  This sketch uses the libraries "Dabble" and "U8g2".
  Check if these are present in Documents\Arduino\libraries.
  If not, install them via Tools > Manage Libraries
  
  Uses Dabble in Gamepad mode (libraries\Dabble\src\GamePadModule.h)

  Info about Gamepad functions: https://thestempedia.com/docs/dabble/game-pad-module/

  This sketch receives commands via Software serial (Dabble) and show them on a display

  Connect USB cable then Upload this sketch.
  Open the Serial Monitor to view test output. Make sure the speed in the Serial Monitor is set to 9600.
 */

#include <U8g2lib.h>
 
// dabble:
#define CUSTOM_SETTINGS
#define INCLUDE_GAMEPAD_MODULE
#include <Dabble.h>


// software i2c:
//U8X8_SSD1306_128X64_NONAME_SW_I2C u8x8(7, 8, U8X8_PIN_NONE);
// hardware i2c:
U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

bool connected=false;

void setup() {
  // Open serial communications
  Serial.begin(9600);

  // Have Dabble connect to Bluetooth Module:
  Dabble.begin(9600, 0, 1); // Baudrate, RX, TX to which bluetooth module is connected, 0,1 = default RX,TX of Uno, Nano
  
  display.begin();
  display.setPowerSave(0);

  display.setFont(u8x8_font_pxplusibmcgathin_f);
  display.drawString(0,0,"Connect");
  display.drawString(0,1,"bluetooth...");
}

void loop() {
  if (Dabble.isAppConnected() && !connected) {
    display.clearDisplay();
    display.drawString(0,0,"Connected");
    connected = true;
  }
  Dabble.processInput();
  if (GamePad.isStartPressed()) message("START");
  else if (GamePad.isSelectPressed()) message("SELECT");
  else if (GamePad.isUpPressed()) message("UP");
  else if (GamePad.isDownPressed()) message("DOWN");
  else if (GamePad.isLeftPressed()) message("LEFT");
  else if (GamePad.isRightPressed()) message("RIGHT");
  else if (GamePad.isSquarePressed()) message("STOP");
  else if (GamePad.isTrianglePressed()) message("Triangle");
  else if (GamePad.isCrossPressed()) message("Cross");
  else if (GamePad.isCirclePressed()) message("Circle");
  delay(100);
}

void message(char* message) {
  display.clearLine(0);
  display.drawString(0,0,message);
}
